/* Talks offline to the Acam IC to set its parameters.
  Part of the PhotonFinish2 project
  Started A. Stummer  3 Jan 2012
*/
#include "PhotonFinish2.h"											   //local project header file.
#include "Unit.h"							//unit specific parameters such as name and IP address.

/********************************* Main() ********************************************************/
int main (void)  {
	char VerNios[20], VerFpga[20];

	ArriaBoot();																  //HARDWARE BOOTS.
	DisplayBoot();

	sprintf (VerNios, "Nios: %s", VER_REV);							 //SHOW NIOS AND FPGA VERSIONS.
	sprintf (VerFpga, "FPGA: %s", ReadVerilogVer());
	DisplayText (VerNios, VerFpga);
	msleep(3000);

	EthernetBoot();															   //BOOT THE ETHERNET.
	DisplayText(UNIT_NAME, "Ready");


	do  {																			   //MAIN LOOP.
		msleep(596);
		AcamRegMirror ^= 0x00000010;											   //toggle Led[2].
		AcamMode[0x10] = AcamRegMirror;
	}while(1);

	return 0;
}


/****************** Boot the Ethernet Port *******************************************************/
void EthernetBoot (void)  {
	char Rev[17];
	#define SCRATCHPAD_VAL  12345

	//Enet[0x00] 						 //readonly MegaCore version[15:0] and cust_version[31:16].
	Enet[0x01] = SCRATCHPAD_VAL;	   //scratchpad, used few lines down to test if can write/read.
	Enet[0x02] = 0x05000520;							//set MAC config register, but no Tx or Rx.
	Enet[0x03] = 0x00C28001;												   //set MAC address...
	Enet[0x04] = 0x00000100;							   //...to 08-80-C2-00-00-01 (ignore 4MSB).
	Enet[0x05] = 1518;														//set max frame length.
	Enet[0x06] = 0x8000;									//set pause quanta (guessing at value).
	Enet[0x07] = TRIPLE_SPEED_ETHERNET_0_RECEIVE_FIFO_DEPTH - 16; //set rx_section_empty threshold.
	Enet[0x08] = 16;											   //set rx_section_full threshold.
	Enet[0x09] = TRIPLE_SPEED_ETHERNET_0_TRANSMIT_FIFO_DEPTH - 16;//set tx_section_empty threshold.
	Enet[0x0A] = 16;											   //set tx_section_full threshold.
	Enet[0x0B] = 8;												   //set rx_almost_empty threshold.
	Enet[0x0C] = 8;													//set rx_almost_full threshold.
	Enet[0x0D] = 8;												   //set tx_almost_empty threshold.
	Enet[0x0E] = 3;													//set tx_almost_full threshold.
	Enet[0x0F] = 0;											  //set mdio_addr0 (guessing at value).
	Enet[0x10] = 1;											  //set mdio_addr1 (guessing at value).
	//Enet[0x11:0x14]																	//reserved.
	Enet[0x15] = 1;										  //set disable_read_timeout (1=on, 0=off).
	//Enet[0x16]								  //readonly read_timeout flag (0=okay, 1=timeout).
	Enet[0x17] = 12;									   //set tx_ipg_length (guessing at value).
	Enet[0x02] |= 3;									//set MAC config register to run Tx and Rx.

	if (Enet[0x01] == SCRATCHPAD_VAL)  {									//TEST THE SCRATCH PAD.
		sprintf (Rev, "Core rev: %X", (uint)Enet[0]);				  //SHOW THE MEGACORE REVISION.
		DisplayText ("Ethernet start..", Rev);
		msleep(3000);
	}
	else  {
		DisplayText ("     ERROR!", " BAD ETHERNET!");						//ETHERNET NOT WORKING.
		msleep(10000);
	}
}


/****************** Read Pushbuttons on Eval Board ***********************************************/
//Returns binary weighted 1 for PB0 and 2 for PB1.
//e.g. if (PushButtons() & 2) printf("Launch missles\n");
int PushButtons (void)  {
	return (int)(3 - ((AcamMode[0x11] >> 24) & 0x03));						 //extract pushbuttons.
}


/****************** Read Verilog Version String **************************************************/
//Returns a string such as "1.2.3".
//e.g.printf ("Verilog version: %s\n", ReadVerilogVer());
char* ReadVerilogVer(void)  {
	sprintf (Buf, "%X.%X.%X",					 //read the verilog version number and other stuff.
		(uint)(AcamMode[0x11] & 0x0F00),												   //major.
		(uint)(AcamMode[0x11] & 0x00F0),												   //minor.
		(uint)(AcamMode[0x11] & 0x000F));												//revision.

	return Buf;
}

/****************** Display Two Lines of Text on the LCD *****************************************/
//Call with the two lines to be displayed, up to 16 chars per line.
void DisplayText (char* Line1, char* Line2)  {
	int CharNum;

	//do{} while(Lcd[0] & 0x80);		//wait for Busy Flag to clear.
	Lcd[0] = 0x01;																   //CLEAR DISPLAY.
	msleep(3);

	for (CharNum = 0;  CharNum < 16;  CharNum++)  {									  //FIRST LINE.
		if (Line1[CharNum] == 0x00)  CharNum = 17;	//eol
		else  {
			//do{} while(Lcd[0] & 0x80);
			Lcd[2] = Line1[CharNum];
			usleep(200);
		}
	}

	//do{} while(Lcd[0] & 0x80);
	Lcd[0] = 0xC0;													   //GOTO START OF SECOND LINE.
	usleep(200);

	for (CharNum = 0;  CharNum < 16;  CharNum++)  {									 //SECOND LINE.
		if (Line2[CharNum] == 0x00)  CharNum = 16;	//eol
		else  {
			//do{} while(Lcd[0] & 0x80);
			Lcd[2] = Line2[CharNum];
			usleep(200);
		}
	}
}


/****************** Boot the Arria II GX Development Board ***************************************/
void ArriaBoot (void)  {
	AcamRegMirror  = 0x00000014;												  //turn on Led[1].
	AcamMode[0x10] = AcamRegMirror;
}


/****************** Boot the LCD display *********************************************************/
//This is what the data sheet says to do so this is what we do.
//Ours is not to wonder why, ours is but to code.  (Tennison)
void DisplayBoot (void)  {
	msleep(50);	/*>15mS power up*/	Lcd[0] = 0x30;		   //Function Set Command: 8-Bit interface.
	msleep(10);	/*>4.1mS delay*/	Lcd[0] = 0x30;		   //Function Set Command: 8-Bit interface.
	msleep(10);	/*>100uS delay*/	Lcd[0] = 0x30;		   //Function Set Command: 8-Bit interface.
	msleep(10);						Lcd[0] = 0x38;		   //Function Set: 8-bit, 2-line, 5x7 font.
	msleep(10);						Lcd[0] = 0x01;								   //clear display.
	msleep(10);						Lcd[0] = 0x06;			//entry mode: increment, shift left(?).
	msleep(10);						Lcd[0] = 0x0C;						  //display on, cursor off.
}
